import { buildProps } from 'element-plus/es/utils/vue/props/runtime';
import type { PropType } from 'vue';

export type TableHeaderItem = {
	prop: string;
	label: string;
	colWidth?: number;
	type?: 'image' | 'tag';
};

export type RowOperateType = {
	text: string;
	icon: string;
	buttonType: '' | 'default' | 'text' | 'success' | 'warning' | 'info' | 'primary' | 'danger';
	click: (row) => void;
};

export const YWTableProps = buildProps({
	/** @description 行 key，树形表格必须要 */
	rowKey: {
		type: String,
		default: 'ID',
	},
	treeProps: {
		type: Object as PropType<{ hasChildren: string; children: string }>,
		default: () => ({
			children: 'Children',
			hasChildren: 'HasChildren',
		}),
	},

	/** @description 表格行样式 */
	rowClassName: {
		type: String,
		default: undefined,
	},
	/** @description 表格数据 */
	data: {
		type: Array,
		default: [],
	},
	/** @description 表头 */
	header: {
		type: Array<TableHeaderItem>,
		default: [],
	},
	/** @description 行操作列 */
	rowOperate: {
		type: Array<RowOperateType>,
		default: [],
	},
	/** @description 是否有可选 */
	hasSelection: {
		type: Boolean,
		default: false,
	},

	/** @description 是否加索引 */
	hasSerialNo: {
		type: Boolean,
		default: false,
	},
	/** @description 操作列宽度 */
	optColWidth: {
		type: Number,
		default: undefined,
	},
} as const);
